====
TODO
====
Work to do on transpolibre.

* Fix broken PDF languages: ar fr he ja zh.

* Fix missing fonts for PDF generation.

* Fix formatting of URLs.

* Fix formatting of inline code with backticks.

* Fix --help in docs for multiple languages.

